@@ -709,7 +709,7 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 fig.show()
 
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'weekly_lo_epochs_details_{title}.xlsx',
+                writer = pd.ExcelWriter(local_root_directory + f'advance_kpis_details_{title}.xlsx',
                                         engine='xlsxwriter')
 
             btd_kpis, ytd_kpis, past_returns = compute_extensive_kpis(data_df=daily_df.copy(),
@@ -721,13 +721,14 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
             btd_kpis.columns = [me_strat]
             past_returns = past_returns.to_frame()
             past_returns.columns = [me_strat]
-            btd_kpis.to_excel(writer, sheet_name='advanced_btd')
-            ytd_kpis.to_excel(writer, sheet_name='advanced_ytd')
-            past_returns.to_excel(writer, sheet_name='common')
             if write_file:
+                btd_kpis.to_excel(writer, sheet_name='advanced_btd')
+                ytd_kpis.to_excel(writer, sheet_name='advanced_ytd')
+                past_returns.to_excel(writer, sheet_name='common')
+
                 writer.save()
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'{me_strat_name}_kpi_{title}.xlsx',
+                writer = pd.ExcelWriter(local_root_directory + f'perf_dd_{me_strat_name}_{title}.xlsx',
                                         engine='xlsxwriter')
                 data.to_excel(writer, sheet_name='kpi')
                 writer.save()
@@ -745,8 +746,43 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
 
             epochkpis_df = epochkpis_df.sort_index()
             epochkpis_df = pd.DataFrame.from_records(epochkpis_df.to_dict()).T
+
+            epochkpis_df['year'] = epochkpis_df.index.year
+            epochkpis_df['month'] = epochkpis_df.index.month
+
+            def rename_month(row):
+                if row['month'] == 1:
+                    return 'January'
+                if row['month'] == 2:
+                    return 'February'
+                if row['month'] == 3:
+                    return 'March'
+                if row['month'] == 4:
+                    return 'April'
+                if row['month'] == 5:
+                    return 'May'
+                if row['month'] == 6:
+                    return 'June'
+                if row['month'] == 7:
+                    return 'July'
+                if row['month'] == 8:
+                    return 'August'
+                if row['month'] == 9:
+                    return 'September'
+                if row['month'] == 10:
+                    return 'October'
+                if row['month'] == 11:
+                    return 'November'
+                if row['month'] == 12:
+                    return 'December'
+
+            epochkpis_df['month'] = epochkpis_df.apply(rename_month, axis=1)
+
+            epochkpis_df = epochkpis_df.set_index(['year', 'month'])
+            epochkpis_df = epochkpis_df.drop(columns=['date', 'epoch_number'])
+
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'monthly_{me_strat_name}_epochs_{title}.xlsx',
+                writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
                                         engine='xlsxwriter')
                 epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
                 writer.save()
